==> pandoc-crossref-0.3.3.0-28-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.3.0
id: pandoc-crossref-0.3.3.0-1Pz1eibUU6Q8ULP26KlLeA
key: pandoc-crossref-0.3.3.0-1Pz1eibUU6Q8ULP26KlLeA
license: GPL-2.0-only
maintainer: root@livid.pp.ru
author: Nikolay Yakimov
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
abi: 19fe16a26443355a8d9b33aa66c64be0
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
import-dirs: /usr/lib/ghc-8.6.1/site-local/pandoc-crossref-0.3.3.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/pandoc-crossref-0.3.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.3.0-1Pz1eibUU6Q8ULP26KlLeA
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-accessor-0.2.2.8-HIkgzlJ5pd86WIK7WTLgcd
    data-accessor-template-0.2.1.16-G0XoOe1w0iDmoWnVy1R9a
    data-accessor-transformers-0.2.1.7-86z1U4b4VmoJsmzquZ7Oae
    data-default-0.7.1.1-9TvgjOMl8fiEDpKR9EhMBO directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pandoc-2.3.1-11V0aOqHLKP8Fp5qWypWao
    pandoc-types-1.17.5.4-LlwIBFA4sXTIfBDuI6SsMa
    roman-numerals-0.5.1.5-98un6W1fKGlBhY1HK0zpS7
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.3.0-37-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.3.0
id: pandoc-crossref-0.3.3.0-ABDw15tvj0MajZeaJYqh8
key: pandoc-crossref-0.3.3.0-ABDw15tvj0MajZeaJYqh8
license: GPL-2.0-only
maintainer: root@livid.pp.ru
author: Nikolay Yakimov
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
abi: 27ab05c57ce9c241064fd152ac336440
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
import-dirs: /usr/lib/ghc-8.6.2/site-local/pandoc-crossref-0.3.3.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/pandoc-crossref-0.3.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.3.0-ABDw15tvj0MajZeaJYqh8
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-accessor-0.2.2.8-32riD7VTnO2INniai0g3x5
    data-accessor-template-0.2.1.16-4PfUdxgAiwHBjHE9ATw5V
    data-accessor-transformers-0.2.1.7-1WdBkBlIKdD2SkmG279Cih
    data-default-0.7.1.1-9TvgjOMl8fiEDpKR9EhMBO directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pandoc-2.4-FDxDfWM2qblCSG1ZznOTx
    pandoc-types-1.17.5.4-IxzRj0GvnKrLjF0Y6XM48s
    roman-numerals-0.5.1.5-98un6W1fKGlBhY1HK0zpS7
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
